unit UnitDemo;

interface

uses
  Windows, sysutils,
  Classes, Controls, Forms, StdCtrls, Db, DBTables, ExtCtrls, Grids,
  DBGrids, ComCtrls, ToolWin, Menus, Searcher, ImgList;

type
  TForm1 = class(TForm)
    DBGrid1: TDBGrid;
    Panel1: TPanel;
    Splitter1: TSplitter;
    Database1: TDatabase;
    Query2: TQuery;
    DataSource1: TDataSource;
    Memo2: TMemo;
    Panel2: TPanel;
    Label1: TLabel;
    MemoFilter: TMemo;
    Splitter2: TSplitter;
    MemoSQL: TMemo;
    Splitter3: TSplitter;
    Query1: TQuery;
    Query1Description: TStringField;
    CoolBar1: TCoolBar;
    ToolBar1: TToolBar;
    tbSearch: TToolButton;
    tbReset: TToolButton;
    ToolButton4: TToolButton;
    tbAlignment: TToolButton;
    PopupMenu1: TPopupMenu;
    faLeft1: TMenuItem;
    faRight1: TMenuItem;
    faReport1: TMenuItem;
    ImageList1: TImageList;
    ToolButton1: TToolButton;
    Label2: TLabel;
    Label3: TLabel;
    lblWeb: TLabel;
    Query1VendorNo: TFloatField;
    Searcher1: TSearcher;
    procedure Query1CalcFields(DataSet: TDataSet);
    procedure FormShow(Sender: TObject);
    procedure Searcher1Prepare(Sender: TObject; const SQL, SQLWhere: String);
    procedure Query1AfterOpen(DataSet: TDataSet);
    procedure tbSearchClick(Sender: TObject);
    procedure tbResetClick(Sender: TObject);
    procedure faLeft1Click(Sender: TObject);
    procedure lblWebClick(Sender: TObject);
  private
  public
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

uses ShellApi;

procedure TForm1.Query1CalcFields(DataSet: TDataSet);
begin
  dataset.fieldbyname('PIPPO').asString := 'PIPPO';
end;

procedure TForm1.FormShow(Sender: TObject);
var
  s: string;
begin
  { connecting the database }
  Database1.Params.Clear;
  s := ExtractFilePath(Application.EXEName) + 'prova.mdb';
  Database1.Params.Add('DATABASE NAME=' + s);
  try
    Database1.Open;
  except
    Application.MessageBox('Error in database connection', 'Searcher', MB_ICONERROR);
    Application.Terminate;
    exit;
  end;
  { setting searcher fields at run time }
  Searcher1.Query := Query1;
  Searcher1.FieldAlignment := faLeft;
  Searcher1.TableName :='parts';
  with Searcher1.SearcherFields.AddField(fkData, 'PartNo', ftFloat, 0, false) do
  begin
    Searcheable := true;
    Field.DisplayLabel := 'Part.No';
  end;
  with Searcher1.SearcherFields.AddField(fkData, 'Description', ftString, 30, false) do
  begin
    Field.DisplayLabel := 'Description';
    Searcheable := true;
    CaseSensitive := true;
    TypeSearch := tsStartingWith;
  end;
  with Searcher1.SearcherFields.AddField(fkLookup, 'Vendor', ftString, 20, false) do
  begin
    TypeSearch := tsEgualTo;
    Searcheable := true;
    Field.Lookup := true;
    Field.DisplayLabel := 'Vendor name';
    Field.LookupDataset := Query2;
    Field.KeyFields := 'VendorNo';
    Field.LookupKeyFields := 'VendorNo';
    Field.LookupResultField := 'VendorName';
  end;
  with Searcher1.SearcherFields.AddField(fkData, 'FieldDate', ftDateTime, 1, false) do
  begin
    Field.DisplayLabel := 'Field Date';
    Field.DisplayWidth := 12;
    Searcheable := true;
    TypeSearch := tsBetween;
  end;
  with Searcher1.SearcherFields.AddField(fkData, 'FieldTrueBool', ftBoolean, 1, false) do
  begin
    Field.DisplayLabel := 'Field Boolean';
    Searcheable := true;
    TypeSearch := tsEgualTo;
  end;
  with Searcher1.SearcherFields.AddField(fkLookup, 'boolean', ftString, 10, false) do
  begin
    Field.DisplayLabel := 'Field Boolean';
    Searcheable := true;
    TypeSearch := tsEgualTo;
    Field.Lookup := true;
    Field.LookupCache := true;
    Field.KeyFields := 'FieldTrueBool';
    LookupList.Add(false, 'Brutto');
    LookupList.Add(true, 'Bello');
  end;
  with Searcher1.SearcherFields.AddField(fkCalculated, 'Pippo', ftString, 10, false) do
  begin
    Field.DisplayLabel := 'Pippo';
    Field.visible := true;
    Field.Calculated := true;
    Searcheable := false;
  end;
  Searcher1.Open;
end;

procedure TForm1.Searcher1Prepare(Sender: TObject; const SQL, SQLWhere: String);
begin
  MemoSQL.Lines.Text := SQL;
  beep;
end;

procedure TForm1.Query1AfterOpen(DataSet: TDataSet);
begin
  MemoFilter.Lines.Text := Searcher1.FilterAsText;
end;

procedure TForm1.tbSearchClick(Sender: TObject);
begin
  Searcher1.Search;
end;

procedure TForm1.tbResetClick(Sender: TObject);
begin
  Searcher1.Reset;
end;

procedure TForm1.faLeft1Click(Sender: TObject);
begin
  Searcher1.FieldAlignment := TFieldAlignment(TComponent(Sender).Tag);
  TMenuItem(Sender).Checked := true;
end;

procedure TForm1.lblWebClick(Sender: TObject);
begin
  ShellExecute(0, 'open', pChar(lblWeb.caption), '', '', SW_SHOWNORMAL);
end;

end.
